import { ReqRecoverPlayerRoom, ResRecoverPlayerRoom } from "../../shared/hallClient/protocols/PtlRecoverPlayerRoom";
import { ErrorCodes } from "../../shared/tsgf/Result";
import { PlayerAuthHelper } from "../../shared/tsgfServer/auth/PlayerAuthHelper";
import { HallApiCall } from "../HallServer";

export default async function (call: HallApiCall<ReqRecoverPlayerRoom, ResRecoverPlayerRoom>) {
    let reqData = call.req;
    if (!reqData.playerId) {
        return await call.error('playerId 不能为空！', { code: ErrorCodes.ParamsError });
    }
    if (!reqData.playerToken) {
        return await call.error('playerToken 不能为空！', { code: ErrorCodes.ParamsError });
    }
    let ret = await PlayerAuthHelper.verificationFromId(reqData.playerId, reqData.playerToken, reqData.updateShowName);
    if (!ret.succ) {
        return await call.error(ret.err, { code: ret.code });
    }
    await call.succ({
        playerId: ret.data.playerId,
        playerToken: ret.data.playerToken,
        currRoomId: ret.data.currRoomId,
    });
}