
import { delay } from "../../../src/shared/tsgf/Utils";
import { assert } from 'chai';
import { authPlayerToken, createAndEnterRoom, hallClient, joinRoom } from "./ApiUtils";
import { ENetworkState } from "../../../src/shared/tsgf/player/IPlayerInfo";
import { GameClient } from "../../../src/shared/gameClient/GameClient";

test('断线重连同时测试网络事件', async function () {


    //==========这里模拟服务端获取playerToken (openid需要按单元测试名区分一下,防止多个单元测试并行时token互踢)
    const auth1 = await authPlayerToken("zum0001_ApiReconnect", "zum1");
    const auth2 = await authPlayerToken("zum0002_ApiReconnect", "zum2");
    const auth3 = await authPlayerToken("zum0003_ApiReconnect", "zum3");
    //==========end
    let playerToken = auth1.playerToken;
    let playerId = auth1.playerId;
    let playerToken2 = auth2.playerToken;
    let playerToken3 = auth3.playerToken;

    let msgCount = 0;

    //玩家1创建房间并进入游戏服务器
    let gameClient1Ret = await createAndEnterRoom(playerToken, playerId, 'zum1');
    let gameClient1 = gameClient1Ret.gameClient;
    let roomId = gameClient1Ret.roomId;
    let gameClient2 = await joinRoom(playerToken2, roomId, 'zum2');
    let gameClient3 = await joinRoom(playerToken3, roomId, 'zum3');


    msgCount = 0;
    gameClient1.onChangePlayerNetworkState = (p) => {
        msgCount++;
        assert.fail('不应该收到自己的网络事件');
    };
    gameClient2.onChangePlayerNetworkState = (p) => {
        msgCount++;
        assert.ok(p.playerId === gameClient1.playerId, '这个时候应该收到玩家1的变更通知');
        assert.ok(p.networkState === ENetworkState.OFFLINE, '这个时候应该收到玩家1的下线通知');
    };
    gameClient3.onChangePlayerNetworkState = (p) => {
        msgCount++;
        assert.ok(p.playerId === gameClient1.playerId, '这个时候应该收到玩家1的变更通知');
        assert.ok(p.networkState === ENetworkState.OFFLINE, '这个时候应该收到玩家1的下线通知');
    };

    let oldToken = gameClient1.playerToken;
    let oldPid = gameClient1.playerId;
    await gameClient1.client.disconnect();

    await delay(200);
    assert.ok(msgCount === 2, '剩下2个人都应该收到网络变更通知, 实际只为' + msgCount);

    msgCount = 0;
    gameClient1.onChangePlayerNetworkState = (p) => {
        msgCount++;
        assert.fail('不应该收到自己的网络事件');
    };
    gameClient2.onChangePlayerNetworkState = (p) => {
        msgCount++;
    };
    gameClient3.onChangePlayerNetworkState = (p) => {
        msgCount++;
    };

    //@ts-ignore
    gameClient1._playerToken = oldToken;
    //@ts-ignore
    gameClient1._playerId = oldPid;
    let recRet = await gameClient1.reconnect();
    assert.ok(recRet.succ, '重连失败!:' + recRet.err);

    await delay(200);
    assert.ok(msgCount === 2, '剩下2个人都应该收到网络变更通知, 实际只为' + msgCount);

    //await delay(5000);//临时延迟5秒，方便我查看一下redis

    oldPid = gameClient1.playerId;
    oldToken = gameClient1.playerToken;
    await gameClient1.client.disconnect();
    await delay(200);

    let onJoinCount = 0;
    gameClient1.onPlayerJoinRoom = (p) => {
        onJoinCount++;
    };
    gameClient2.onPlayerJoinRoom = (p) => {
        onJoinCount++;
    };
    gameClient3.onPlayerJoinRoom = (p) => {
        onJoinCount++;
    };
    msgCount = 0;
    let roomIdRet = await hallClient.recoverPlayerRoom(oldPid, oldToken, '全新的名字');
    assert.ok(roomIdRet.succ, '恢复失败!' + roomIdRet.err);

    //先在大厅获取房间的注册信息
    let getRoomInfo = await hallClient.getRoomRegInfo(oldToken, roomIdRet.data!);
    assert.ok(getRoomInfo.succ, '恢复失败!' + getRoomInfo.err);

    //开始游戏服务器的重连操作
    gameClient1 = new GameClient(getRoomInfo.data!.gameServerUrl, oldToken);
    let reconnectRet = await gameClient1.reconnect();
    assert.ok(reconnectRet.succ, '恢复失败!' + reconnectRet.err);

    await delay(200);
    assert.ok(onJoinCount === 0, '应该有0个玩家收到玩家加入通知, 实际为' + onJoinCount);
    assert.ok(msgCount === 2, '剩下2个人都应该收到网络变更通知, 实际为' + msgCount);




    await gameClient1.disconnect();
    await gameClient2.disconnect();
    await gameClient3.disconnect();
}, 60 * 1000)